@@ -646,7 +646,6 @@ as_cache_components_to_internal_xb (AsCache *cache,
 	for (guint i = 0; i < cpts->len; i++) {
 		xmlNode *cnode;
 		g_autoptr(XbBuilderNode) xbnode = NULL;
-		g_autoptr(XbBuilderNode) tmp_node = NULL;
 		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
 
 		/* refine component data */
@@ -1910,8 +1909,8 @@ as_cache_get_components_by_bundle_id (AsCache *cache, AsBundleKind kind, const g
 }
 
 typedef struct {
-	AsSearchTokenMatch	match_value;
-	XbQuery			*query;
+	AsSearchTokenMatch match_value;
+	XbQuery *query;
 } AsFTSearchHelper;
 
 static void
@@ -1932,7 +1931,10 @@ as_cache_search_component_node_term (GPtrArray *array, XbNode *cpt_node, const g
 		g_auto(XbQueryContext) context = XB_QUERY_CONTEXT_INIT ();
 		AsFTSearchHelper *helper = g_ptr_array_index (array, i);
 
-		xb_value_bindings_bind_str (xb_query_context_get_bindings (&context), 0, term, NULL);
+		xb_value_bindings_bind_str (xb_query_context_get_bindings (&context),
+					    0,
+					    term,
+					    NULL);
 		n = xb_node_query_with_context (cpt_node, helper->query, &context, NULL);
 		if (n != NULL)
 			match_value |= helper->match_value;
